@@ -41,11 +41,11 @@ sub _get_fields_map
 
 use Carp;
 
-sub _initialize
+sub _init
 {
     my $self = shift;
 
-    $self->NEXT::_initialize(@_);
+    $self->NEXT::_init(@_);
 
     my ($args) = @_;
     
