@@ -30,11 +30,11 @@ sub _get_private_fields
 
 __PACKAGE__->mk_accessors(@fields);
 
-sub _initialize
+sub _init
 {
     my $self = shift;
 
-    $self->NEXT::_initialize(@_);
+    $self->NEXT::_init(@_);
 
     $self->_more_results([]);
 
